-- 党员干部学习
DROP TABLE IF EXISTS `party_cadre_study`;
CREATE TABLE `party_cadre_study`
(
    id                        BIGINT       NOT NULL COMMENT '主键编号'
        PRIMARY KEY,
    create_user_id            BIGINT       NULL COMMENT '创建人',
    create_date               DATETIME     NULL COMMENT '创建时间',
    modify_user_id            BIGINT       NULL COMMENT '修改人',
    modify_date               DATETIME     NULL COMMENT '修改时间',
    delete_mark               INT          NOT NULL COMMENT '删除标记',
    enabled_mark              INT          NOT NULL COMMENT '有效标志',
    sort_code                 INT          NULL COMMENT '序号',

    party_tissue_id           BIGINT       NOT NULL COMMENT '党组织主键id(party_tissue_manager)',
    party_tissue_name         VARCHAR(256) NOT NULL COMMENT '党组织名称',
    party_tissue_code         VARCHAR(256) NOT NULL COMMENT '党组织编号',

    party_train_way_carrier   VARCHAR(500) NOT NULL COMMENT '党员干部学习培训主要途径和载体',
    party_train_way_content   VARCHAR(500) NOT NULL COMMENT '党员干部学习培训内容',

    start_time                DATE         NOT NULL COMMENT '活动开始日期',
    end_time                  DATE         NOT NULL COMMENT '活动结束日期',

    participate_teacher_count INT          NULL COMMENT '参与教师数',
    participate_student_count INT          NULL COMMENT '参与学生数'
) ENGINE = INNODB
  DEFAULT CHARSET = utf8mb4
    COMMENT '党员干部学习';

-- 党员干部学习活动参与人
DROP TABLE IF EXISTS `party_cadre_study_participant`;
CREATE TABLE `party_cadre_study_participant`
(
    id                   BIGINT       NOT NULL COMMENT '主键编号'
        PRIMARY KEY,
    create_user_id       BIGINT       NULL COMMENT '创建人',
    create_date          DATETIME     NULL COMMENT '创建时间',
    modify_user_id       BIGINT       NULL COMMENT '修改人',
    modify_date          DATETIME     NULL COMMENT '修改时间',
    delete_mark          INT          NOT NULL COMMENT '删除标记',
    enabled_mark         INT          NOT NULL COMMENT '有效标志',
    sort_code            INT          NULL COMMENT '序号',

    party_cadre_study_id BIGINT       NULL COMMENT '党员干部学习主键id（party_cadre_study）',
    participant_id       BIGINT       NULL COMMENT '活动参与人id',
    participant_remark   VARCHAR(256) NULL COMMENT '活动参与人类型',
    participant_username VARCHAR(256) NULL COMMENT '活动参与人oa',
    participant_user_id  VARCHAR(256) NULL COMMENT '活动参与人学号，工号',
    participant_name     VARCHAR(256) NULL COMMENT '活动参与人姓名'
) ENGINE = INNODB
  DEFAULT CHARSET = utf8mb4
    COMMENT '党员干部学习活动参与人';

# 数据字典
# par_part 党员干部学习培训内容
# 值  名称               编号
# 1 党的理论              par_part1
# 2 相关政策文件            par_part2
# 3 党规党纪及国家法律法规   par_part3
# 4 教育教学业务            par_part4
# 5 学校管理              par_part5
# 6 文化建设              par_part6
# 7 经济方面              par_part7
# 8 互联网与新媒体方面     par_part8
# 9 心理健康              par_part9
# 10 师德师风             par_part10
# 99 其他                 par_part99
#
# party_way 党员干部学习培训主要途径和载体
# 值  名称               编号
# 1  实践活动             party_way1
# 2  会议               party_way2
# 3  讲座报告             party_way3
# 4  学校定期集中学习         party_way4
# 5  支部定期集中学习         party_way5
# 6   微信 QQ               party_way6
# 7  移动端培训平台          party_way7
# 8  分发图书资料           party_way8
# 9  个人学习             party_way9
# 10 在线教育网站           party_way10
# 11 参观学习             party_way11
# 99 其他                   party_way99

DROP TABLE IF EXISTS party_class_manage;
CREATE TABLE party_class_manage
(
    id                        BIGINT       NOT NULL COMMENT '主键编号' PRIMARY KEY,
    create_user_id            BIGINT       NULL COMMENT '创建人',
    create_date               DATETIME     NULL COMMENT '创建时间',
    modify_user_id            BIGINT       NULL COMMENT '修改人',
    modify_date               DATETIME     NULL COMMENT '修改时间',
    delete_mark               INT          NOT NULL COMMENT '删除标记',
    enabled_mark              INT          NOT NULL COMMENT '有效标志',
    sort_code                 INT          NULL COMMENT '序号',

    party_tissue_name         VARCHAR(256) NOT NULL COMMENT '党组织名称',
    party_tissue_code         VARCHAR(256) NOT NULL COMMENT '党组织编号',
    party_tissue_id           BIGINT       NOT NULL COMMENT '党组织主键id(party_tissue_manager)',

    activity_type             VARCHAR(256) NOT NULL COMMENT '活动形式',
    speaker_name              VARCHAR(256) NULL COMMENT '党课主讲人',

    start_time                DATE         NOT NULL COMMENT '活动开始时间',
    end_time                  DATE         NOT NULL COMMENT '活动结束时间',

    activities_content        TEXT         NULL COMMENT '活动内容',

    participate_teacher_count INT          NULL COMMENT '参与教师数',
    participate_student_count INT          NULL COMMENT '参与学生数'

) ENGINE = INNODB
  DEFAULT CHARSET = utf8mb4
    COMMENT ='党课管理数据表';


DROP TABLE IF EXISTS party_class_manage_participant;
CREATE TABLE party_class_manage_participant
(
    id                    BIGINT       NOT NULL COMMENT '主键编号' PRIMARY KEY,
    create_user_id        BIGINT       NULL COMMENT '创建人',
    create_date           DATETIME     NULL COMMENT '创建时间',
    modify_user_id        BIGINT       NULL COMMENT '修改人',
    modify_date           DATETIME     NULL COMMENT '修改时间',
    delete_mark           INT          NOT NULL COMMENT '删除标记',
    enabled_mark          INT          NOT NULL COMMENT '有效标志',
    sort_code             INT          NULL COMMENT '序号',

    party_class_manage_id BIGINT       NOT NULL COMMENT '党课管理id',

    participant_id        BIGINT       NULL COMMENT '活动参与人id',
    participant_remark    VARCHAR(256) NULL COMMENT '活动参与人类型',
    participant_username  VARCHAR(256) NULL COMMENT '活动参与人oa',
    participant_user_id   VARCHAR(256) NULL COMMENT '活动参与人学号，工号',
    participant_name      VARCHAR(256) NULL COMMENT '活动参与人姓名'

) ENGINE = INNODB
  DEFAULT CHARSET = utf8mb4
    COMMENT ='党课活动参与人表';

-- 党建活动
DROP TABLE IF EXISTS `party_build_event`;
CREATE TABLE party_build_event
(
    id                 BIGINT       NOT NULL COMMENT '主键编号'
        PRIMARY KEY,
    create_user_id     BIGINT       NULL COMMENT '创建人',
    create_date        DATETIME     NULL COMMENT '创建时间',
    modify_user_id     BIGINT       NULL COMMENT '修改人',
    modify_date        DATETIME     NULL COMMENT '修改时间',
    delete_mark        INT          NOT NULL COMMENT '删除标记',
    enabled_mark       INT          NOT NULL COMMENT '有效标志',
    sort_code          INT          NULL COMMENT '序号',

    event_type         VARCHAR(255) NOT NULL COMMENT '活动类型',
    party_tissue_id    BIGINT       NOT NULL COMMENT '党组织主键id(party_tissue_manager)',
    party_tissue_name  VARCHAR(256) NOT NULL COMMENT '党组织名称',
    party_tissue_code  VARCHAR(256) NOT NULL COMMENT '党组织编号',
    event_address      VARCHAR(255) NULL COMMENT '活动地点',
    event_content      TEXT         NULL COMMENT '活动内容',
    event_start_time   DATE         NOT NULL COMMENT '活动开始时间',
    event_end_time     DATE         NOT NULL COMMENT '活动结束时间',
    attend_teacher_num INT          NULL COMMENT '参于教师数',
    attend_student_num INT          NULL COMMENT '参于学生数'
) ENGINE = INNODB
  DEFAULT CHARSET = utf8mb4
    COMMENT ='党建活动';

-- 党建活动参与人员
DROP TABLE IF EXISTS `party_build_event_participant`;
CREATE TABLE `party_build_event_participant`
(
    id                   BIGINT       NOT NULL COMMENT '主键编号'
        PRIMARY KEY,
    create_user_id       BIGINT       NULL COMMENT '创建人',
    create_date          DATETIME     NULL COMMENT '创建时间',
    modify_user_id       BIGINT       NULL COMMENT '修改人',
    modify_date          DATETIME     NULL COMMENT '修改时间',
    delete_mark          INT          NOT NULL COMMENT '删除标记',
    enabled_mark         INT          NOT NULL COMMENT '有效标志',
    sort_code            INT          NULL COMMENT '序号',

    party_build_event_id BIGINT       NULL COMMENT '党建活动主键id（party_build_event）',
    participant_id       BIGINT       NULL COMMENT '参与活动人id',
    participant_remark   VARCHAR(256) NULL COMMENT '活动参与人类型',
    participant_username VARCHAR(256) NULL COMMENT '活动参与人oa',
    participant_user_id  VARCHAR(256) NULL COMMENT '活动参与人学号，工号',
    participant_name     VARCHAR(256) NULL COMMENT '活动参与人姓名'
) ENGINE = INNODB
  DEFAULT CHARSET = utf8mb4
    COMMENT '党建活动参与人员';

ALTER TABLE `whitelist_management`   
  CHANGE `phone` `phone` VARCHAR(20) NOT NULL   COMMENT '手机号';

DROP TABLE IF EXISTS patrol_offline_courses;   
CREATE TABLE `patrol_offline_courses` (
  `id` BIGINT NOT NULL,
  `create_user_id` BIGINT DEFAULT NULL COMMENT '创建人',
  `create_date` DATE DEFAULT NULL COMMENT '创建时间',
  `modify_user_id` BIGINT DEFAULT NULL COMMENT '修改人',
  `modify_date` DATE DEFAULT NULL COMMENT '修改日期',
  `delete_mark` INT DEFAULT NULL COMMENT '删除标记',
  `enabled_mark` INT DEFAULT NULL COMMENT '有效标记',
  `semester_id` BIGINT DEFAULT NULL COMMENT '学期',
  `now_date` DATETIME DEFAULT NULL COMMENT '当前日期',
  `classroom_id` BIGINT DEFAULT NULL COMMENT '教室id',
  `class_id` BIGINT DEFAULT NULL COMMENT '班级id',
  `now_course` BIGINT DEFAULT NULL COMMENT '当前课程id',
  `now_teacher_id` BIGINT DEFAULT NULL COMMENT '当前教师id',
  `should_arrive_number` INT DEFAULT NULL COMMENT '应到人数',
  `leave_number` INT DEFAULT NULL COMMENT '请假人数',
  `actua_arrive_number` INT DEFAULT NULL COMMENT '实到人数',
  `not_arrived_number` INT DEFAULT NULL COMMENT '未到人数',
  `attendance_status` VARCHAR(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_0900_ai_ci DEFAULT NULL COMMENT '出勤情况',
  `to_post_status` VARCHAR(255) DEFAULT NULL COMMENT '到岗情况',
  `class_interaction` VARCHAR(255) DEFAULT NULL COMMENT '课堂互动情况',
  `teach_condition` VARCHAR(255) DEFAULT NULL COMMENT '教学条件情况',
  `class_discipline` VARCHAR(255) DEFAULT NULL COMMENT '上课纪律',
  `remark` VARCHAR(500) DEFAULT NULL COMMENT '备注',
  `status` INT DEFAULT NULL COMMENT '流程状态',
  PRIMARY KEY (`id`)
) ENGINE=INNODB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci COMMENT='线下巡课表';

-- --------------------------------------------------------------------------------------------
-- 考试科目成绩表
-- --------------------------------------------------------------------------------------------
DROP TABLE IF EXISTS exam_subject_score;   
CREATE TABLE `exam_subject_score` (
  `id` BIGINT NOT NULL,
  `create_user_id` BIGINT DEFAULT NULL COMMENT '创建人',
  `create_date` DATETIME DEFAULT NULL COMMENT '创建时间',
  `modify_user_id` BIGINT DEFAULT NULL COMMENT '修改人',
  `modify_date` DATETIME DEFAULT NULL COMMENT '修改日期',
  `delete_mark` INT DEFAULT NULL COMMENT '删除标记',
  `enabled_mark` INT DEFAULT NULL COMMENT '有效标记',
  `semester_id` BIGINT DEFAULT NULL COMMENT '学期',
  `milexamname` VARCHAR(50) DEFAULT NULL COMMENT '考试计划',
  `milexamid` BIGINT DEFAULT NULL COMMENT '考试计划id',
  `course_subject_id` BIGINT DEFAULT NULL COMMENT '课程科目id(base_course_subject)',
  `coursename` VARCHAR(50) DEFAULT NULL COMMENT '课程名称',
  `score` INT DEFAULT NULL COMMENT '分数',
  `class_ranking` INT DEFAULT NULL COMMENT '班级排名',
  `grade_ranking` INT DEFAULT NULL COMMENT '年级排名',
  `user_id` BIGINT DEFAULT NULL COMMENT '学生id(xjr_user)',
  PRIMARY KEY (`id`)
) ENGINE=INNODB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci COMMENT='考试科目成绩表';


-- --------------------------------------------------------------------------------------------
-- 晓羊策学考试计划表
-- --------------------------------------------------------------------------------------------
DROP TABLE IF EXISTS xycxedu_exam_list;   
CREATE TABLE `xycxedu_exam_list` (
  `id` BIGINT NOT NULL,
  `create_date` DATETIME DEFAULT NULL COMMENT '创建时间',
  `modify_date` DATETIME DEFAULT NULL COMMENT '修改日期',
  `delete_mark` INT DEFAULT NULL COMMENT '删除标记',
  `milexamid` BIGINT DEFAULT NULL COMMENT '考试计划id',
  `milexamname` VARCHAR(50) DEFAULT NULL COMMENT '考试计划名称',
  regyear INT DEFAULT NULL COMMENT '学年',
  grade VARCHAR(20) DEFAULT NULL COMMENT '年级名称',
  sdate DATE DEFAULT NULL COMMENT '考试时间',
  PRIMARY KEY (`id`)
) ENGINE=INNODB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci COMMENT='晓羊策学考试计划表';

-- --------------------------------------------------------------------------------------------
-- 考试计划维护
-- --------------------------------------------------------------------------------------------
DROP TABLE IF EXISTS exam_plan;   
CREATE TABLE `exam_plan` (
  `id` BIGINT NOT NULL,
  `create_user_id` BIGINT DEFAULT NULL COMMENT '创建人',
  `create_date` DATETIME DEFAULT NULL COMMENT '创建时间',
  `modify_user_id` BIGINT DEFAULT NULL COMMENT '修改人',
  `modify_date` DATETIME DEFAULT NULL COMMENT '修改日期',
  `delete_mark` INT DEFAULT NULL COMMENT '删除标记',
  `enabled_mark` INT DEFAULT NULL COMMENT '有效标记',
  `semester_id` BIGINT DEFAULT NULL COMMENT '学期id',
  `name` VARCHAR(50) DEFAULT NULL COMMENT '考试计划名称',
  milexamids TEXT DEFAULT NULL COMMENT '晓羊策学考试计划id',
  PRIMARY KEY (`id`)
) ENGINE=INNODB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci COMMENT='考试计划维护';


-- --------------------------------------------------------------------------------------------
-- 赛事活动
-- --------------------------------------------------------------------------------------------
DROP TABLE IF EXISTS match_activity;   
CREATE TABLE `match_activity` (
  `id` BIGINT NOT NULL,
  `create_user_id` BIGINT DEFAULT NULL COMMENT '创建人',
  `create_date` DATETIME DEFAULT NULL COMMENT '创建时间',
  `modify_user_id` BIGINT DEFAULT NULL COMMENT '修改人',
  `modify_date` DATETIME DEFAULT NULL COMMENT '修改日期',
  `delete_mark` INT DEFAULT NULL COMMENT '删除标记',
  `enabled_mark` INT DEFAULT NULL COMMENT '有效标记',
  `name` VARCHAR(50) DEFAULT NULL COMMENT '赛事名称',
  place VARCHAR(50) DEFAULT NULL COMMENT '活动地点',
  start_date DATETIME DEFAULT NULL COMMENT '开始时间',
  end_date DATETIME DEFAULT NULL COMMENT '结束时间',
  TYPE VARCHAR(50) DEFAULT NULL COMMENT '活动类型',
  org_id BIGINT DEFAULT NULL COMMENT '组织部门(xjr_department)',
  STATUS INT DEFAULT 0 COMMENT '状态(0:未发布 1:已发布)',
  PRIMARY KEY (`id`)
) ENGINE=INNODB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci COMMENT='赛事活动';
